summaryrefslogtreecommitdiffstats
path: root/akregator/src/mk4storage/metakit
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/mk4storage/metakit')
-rw-r--r--akregator/src/mk4storage/metakit/CHANGES2
-rw-r--r--akregator/src/mk4storage/metakit/src/column.cpp6
-rw-r--r--akregator/src/mk4storage/metakit/src/custom.cpp128
-rw-r--r--akregator/src/mk4storage/metakit/src/handler.cpp18
-rw-r--r--akregator/src/mk4storage/metakit/src/handler.h2
-rw-r--r--akregator/src/mk4storage/metakit/src/handler.inl2
-rw-r--r--akregator/src/mk4storage/metakit/src/remap.cpp12
-rw-r--r--akregator/src/mk4storage/metakit/tests/ok/f07a.txt2
-rw-r--r--akregator/src/mk4storage/metakit/tests/tformat.cpp2
9 files changed, 87 insertions, 87 deletions
diff --git a/akregator/src/mk4storage/metakit/CHANGES b/akregator/src/mk4storage/metakit/CHANGES
index 1e1761ca..4f167afb 100644
--- a/akregator/src/mk4storage/metakit/CHANGES
+++ b/akregator/src/mk4storage/metakit/CHANGES
@@ -298,7 +298,7 @@
2003-01-24 Fixed cleanup order bug in Mk4tcl
There was a long-standing bug in Mk4tcl, in which cleanup order of
- MkPath objects caused them to access their MkWorkspace tqparent even
+ MkPath objects caused them to access their MkWorkspace parent even
though it was already deleted. This may have caused some of the
crash-on-exit bugs in the past.
diff --git a/akregator/src/mk4storage/metakit/src/column.cpp b/akregator/src/mk4storage/metakit/src/column.cpp
index dda916ab..2d191c64 100644
--- a/akregator/src/mk4storage/metakit/src/column.cpp
+++ b/akregator/src/mk4storage/metakit/src/column.cpp
@@ -770,7 +770,7 @@ void c4_Column::StoreBytes(t4_i32 pos_, const c4_Bytes& buffer_)
t4_i32 c4_Column::PullValue(const t4_byte*& ptr_)
{
- t4_i32 tqmask = *ptr_ ? 0 : ~0;
+ t4_i32 mask = *ptr_ ? 0 : ~0;
t4_i32 v = 0;
for (;;) {
@@ -779,7 +779,7 @@ t4_i32 c4_Column::PullValue(const t4_byte*& ptr_)
break;
}
- return tqmask ^ (v - 0x80); // oops, last byte had bit 7 set
+ return mask ^ (v - 0x80); // oops, last byte had bit 7 set
}
void c4_Column::PushValue(t4_byte*& ptr_, t4_i32 v_)
@@ -1398,7 +1398,7 @@ void c4_ColOfInts::ResizeData(int index_, int count_, bool clear_)
/* _currwidth 1: 2: 4:
* shiftPos 3 2 1 shift the offset right this much
- * maskPos 7 3 1 tqmask the offset with this
+ * maskPos 7 3 1 mask the offset with this
*/
const int shiftPos = _currWidth == 4 ? 1 : 4 - _currWidth;
diff --git a/akregator/src/mk4storage/metakit/src/handler.cpp b/akregator/src/mk4storage/metakit/src/handler.cpp
index 9bacfc9f..6c68c5c3 100644
--- a/akregator/src/mk4storage/metakit/src/handler.cpp
+++ b/akregator/src/mk4storage/metakit/src/handler.cpp
@@ -78,13 +78,13 @@ void c4_Handler::Move(int from_, int to_)
// c4_HandlerSeq
c4_HandlerSeq::c4_HandlerSeq (c4_Persist* persist_)
- : _persist (persist_), _field (0), _tqparent (0), _numRows (0)
+ : _persist (persist_), _field (0), _parent (0), _numRows (0)
{
}
c4_HandlerSeq::c4_HandlerSeq (c4_HandlerSeq& owner_, c4_Handler* handler_)
: _persist (owner_.Persist()), _field (owner_.FindField(handler_)),
- _tqparent (&owner_), _numRows (0)
+ _parent (&owner_), _numRows (0)
{
for (int i = 0; i < NumFields(); ++i) {
c4_Field& field = Field(i);
@@ -98,7 +98,7 @@ c4_HandlerSeq::c4_HandlerSeq (c4_HandlerSeq& owner_, c4_Handler* handler_)
c4_HandlerSeq::~c4_HandlerSeq ()
{
- const bool rootLevel = _tqparent == this;
+ const bool rootLevel = _parent == this;
c4_Persist* pers = _persist;
if (rootLevel && pers != 0)
@@ -129,7 +129,7 @@ c4_Persist* c4_HandlerSeq::Persist() const
void c4_HandlerSeq::DefineRoot()
{
d4_assert(_field == 0);
- d4_assert(_tqparent == 0);
+ d4_assert(_parent == 0);
SetNumRows(1);
@@ -137,7 +137,7 @@ void c4_HandlerSeq::DefineRoot()
_field = d4_new c4_Field (desc);
d4_assert(!*desc);
- _tqparent = this;
+ _parent = this;
}
c4_Handler* c4_HandlerSeq::CreateHandler(const c4_Property& prop_)
@@ -162,7 +162,7 @@ void c4_HandlerSeq::DetachFromParent()
_field = 0;
}
- _tqparent = 0;
+ _parent = 0;
}
void c4_HandlerSeq::DetachFromStorage(bool full_)
@@ -293,7 +293,7 @@ void c4_HandlerSeq::Restructure(c4_Field& field_, bool remove_)
}
}
- if (_tqparent == this)
+ if (_parent == this)
delete ofld; // the root table owns its field structure tree
}
@@ -398,8 +398,8 @@ void c4_HandlerSeq::ExchangeEntries(int srcPos_, c4_HandlerSeq& dst_, int dstPos
c4_HandlerSeq& t2 = dst_.SubEntry(col, dstPos_);
// adjust the parents
- t1._tqparent = this;
- t2._tqparent = &dst_;
+ t1._parent = this;
+ t2._parent = &dst_;
// reattach the proper field structures
t1.Restructure(Field(col), false);
diff --git a/akregator/src/mk4storage/metakit/src/handler.h b/akregator/src/mk4storage/metakit/src/handler.h
index 7cf2efdf..6003f625 100644
--- a/akregator/src/mk4storage/metakit/src/handler.h
+++ b/akregator/src/mk4storage/metakit/src/handler.h
@@ -88,7 +88,7 @@ class c4_HandlerSeq : public c4_Sequence
c4_PtrArray _handlers;
c4_Persist* _persist;
c4_Field* _field;
- c4_HandlerSeq* _tqparent;
+ c4_HandlerSeq* _parent;
int _numRows;
public:
diff --git a/akregator/src/mk4storage/metakit/src/handler.inl b/akregator/src/mk4storage/metakit/src/handler.inl
index 10d45f3c..75321f9c 100644
--- a/akregator/src/mk4storage/metakit/src/handler.inl
+++ b/akregator/src/mk4storage/metakit/src/handler.inl
@@ -84,7 +84,7 @@ d4_inline const c4_Sequence* c4_HandlerSeq::HandlerContext(int) const
d4_inline c4_HandlerSeq& c4_HandlerSeq::Parent() const
{
- return *_tqparent;
+ return *_parent;
}
/////////////////////////////////////////////////////////////////////////////
diff --git a/akregator/src/mk4storage/metakit/src/remap.cpp b/akregator/src/mk4storage/metakit/src/remap.cpp
index 9bc9b440..cc8175df 100644
--- a/akregator/src/mk4storage/metakit/src/remap.cpp
+++ b/akregator/src/mk4storage/metakit/src/remap.cpp
@@ -258,10 +258,10 @@ t4_i32 c4_HashViewer::CalcHash(c4_Cursor cursor_) const
int c4_HashViewer::LookDict(t4_i32 hash_, c4_Cursor cursor_) const
{
- const unsigned int tqmask = _map.GetSize() - 2;
+ const unsigned int mask = _map.GetSize() - 2;
/* We must come up with (i, incr) such that 0 <= i < _size
and 0 < incr < _size and both are a function of hash */
- int i = tqmask & ~hash_;
+ int i = mask & ~hash_;
/* We use ~hash_ instead of hash_, as degenerate hash functions, such
as for ints <sigh>, can have lots of leading zeros. It's not
really a performance risk, but better safe than sorry. */
@@ -272,14 +272,14 @@ int c4_HashViewer::LookDict(t4_i32 hash_, c4_Cursor cursor_) const
/* Derive incr from hash_, just to make it more arbitrary. Note that
incr must not be 0, or we will get into an infinite loop.*/
- unsigned incr = (hash_ ^ ((unsigned long) hash_ >> 3)) & tqmask;
+ unsigned incr = (hash_ ^ ((unsigned long) hash_ >> 3)) & mask;
if (!incr)
- incr = tqmask;
+ incr = mask;
int poly = GetPoly();
for (;;)
{
- i = (i+incr) & tqmask;
+ i = (i+incr) & mask;
if (IsUnused(i))
break;
if (Hash(i) == hash_ && KeySame(Row(i), cursor_))
@@ -288,7 +288,7 @@ int c4_HashViewer::LookDict(t4_i32 hash_, c4_Cursor cursor_) const
freeslot = i;
/* Cycle through GF(2^n)-{0} */
incr = incr << 1;
- if (incr > tqmask)
+ if (incr > mask)
incr ^= poly; /* This will implicitely clear the highest bit */
}
diff --git a/akregator/src/mk4storage/metakit/tests/ok/f07a.txt b/akregator/src/mk4storage/metakit/tests/ok/f07a.txt
index 8f3ed207..79963d7b 100644
--- a/akregator/src/mk4storage/metakit/tests/ok/f07a.txt
+++ b/akregator/src/mk4storage/metakit/tests/ok/f07a.txt
@@ -1,3 +1,3 @@
VIEW 1 rows = dict:V
0: subview 'dict'
- VIEW 0 rows = tqparent:I index:I view:V
+ VIEW 0 rows = parent:I index:I view:V
diff --git a/akregator/src/mk4storage/metakit/tests/tformat.cpp b/akregator/src/mk4storage/metakit/tests/tformat.cpp
index 67530b7f..ba6e9254 100644
--- a/akregator/src/mk4storage/metakit/tests/tformat.cpp
+++ b/akregator/src/mk4storage/metakit/tests/tformat.cpp
@@ -207,7 +207,7 @@ void TestFormat()
c4_View v3 = pView (v2[0]);
A(v3.GetSize() == 2);
*/
- #define FORMAT07 "dict[tqparent:I,index:I,view[name:S,type:S,child:I]]"
+ #define FORMAT07 "dict[parent:I,index:I,view[name:S,type:S,child:I]]"
c4_Storage s1 ("f07a", 1);
s1.SetStructure(FORMAT07);
diff --git a/akregator/src/mk4storage/metakit/src/custom.cpp b/akregator/src/mk4storage/metakit/src/custom.cpp
index 6ed1d5ab..a6275cea 100644
--- a/akregator/src/mk4storage/metakit/src/custom.cpp
+++ b/akregator/src/mk4storage/metakit/src/custom.cpp
@@ -233,7 +233,7 @@ bool c4_CustomViewer::RemoveRows(int, int)
class c4_SliceViewer : public c4_CustomViewer
{
- c4_View _tqparent;
+ c4_View _parent;
int _first, _limit, _step;
public:
@@ -249,7 +249,7 @@ public:
};
c4_SliceViewer::c4_SliceViewer (c4_Sequence& seq_, int first_, int limit_, int step_)
- : _tqparent (&seq_), _first (first_), _limit (limit_), _step (step_)
+ : _parent (&seq_), _first (first_), _limit (limit_), _step (step_)
{
d4_assert(_step != 0);
}
@@ -260,12 +260,12 @@ c4_SliceViewer::~c4_SliceViewer ()
c4_View c4_SliceViewer::GetTemplate()
{
- return _tqparent.Clone(); // could probably return _tqparent just as well
+ return _parent.Clone(); // could probably return _parent just as well
}
int c4_SliceViewer::GetSize()
{
- int n = _limit >= 0 ? _limit : _tqparent.GetSize();
+ int n = _limit >= 0 ? _limit : _parent.GetSize();
if (n < _first)
n = _first;
@@ -277,14 +277,14 @@ bool c4_SliceViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
row_ = _first + _step * (_step > 0 ? row_ : row_ - GetSize() + 1);
- return _tqparent.GetItem(row_, col_, buf_);
+ return _parent.GetItem(row_, col_, buf_);
}
bool c4_SliceViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
{
row_ = _first + _step * (_step > 0 ? row_ : row_ - GetSize() + 1);
- _tqparent.SetItem(row_, col_, buf_);
+ _parent.SetItem(row_, col_, buf_);
return true;
}
@@ -297,7 +297,7 @@ bool c4_SliceViewer::InsertRows(int pos_, c4_Cursor value_, int count_)
if (_limit >= 0)
_limit += count_;
- _tqparent.InsertAt(pos_, *value_, count_);
+ _parent.InsertAt(pos_, *value_, count_);
return true;
}
@@ -310,7 +310,7 @@ bool c4_SliceViewer::RemoveRows(int pos_, int count_)
if (_limit >= 0)
_limit -= count_;
- _tqparent.RemoveAt(pos_, count_);
+ _parent.RemoveAt(pos_, count_);
return true;
}
@@ -323,7 +323,7 @@ c4_CustomViewer* f4_CustSlice(c4_Sequence& seq_, int first_, int limit_, int ste
class c4_ProductViewer : public c4_CustomViewer
{
- c4_View _tqparent, _argView, _template;
+ c4_View _parent, _argView, _template;
public:
c4_ProductViewer (c4_Sequence& seq_, const c4_View& view_);
@@ -335,7 +335,7 @@ public:
};
c4_ProductViewer::c4_ProductViewer (c4_Sequence& seq_, const c4_View& view_)
- : _tqparent (&seq_), _argView (view_), _template (_tqparent.Clone())
+ : _parent (&seq_), _argView (view_), _template (_parent.Clone())
{
for (int i = 0; i < _argView.NumProperties(); ++i)
_template.AddProperty(_argView.NthProperty(i));
@@ -352,12 +352,12 @@ c4_View c4_ProductViewer::GetTemplate()
int c4_ProductViewer::GetSize()
{
- return _tqparent.GetSize() * _argView.GetSize();
+ return _parent.GetSize() * _argView.GetSize();
}
bool c4_ProductViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
if (col_ < v.NumProperties())
{
@@ -384,7 +384,7 @@ c4_CustomViewer* f4_CustProduct(c4_Sequence& seq_, const c4_View& view_)
class c4_RemapWithViewer : public c4_CustomViewer
{
- c4_View _tqparent, _argView;
+ c4_View _parent, _argView;
public:
c4_RemapWithViewer (c4_Sequence& seq_, const c4_View& view_);
@@ -397,7 +397,7 @@ public:
};
c4_RemapWithViewer::c4_RemapWithViewer (c4_Sequence& seq_, const c4_View& view_)
- : _tqparent (&seq_), _argView (view_)
+ : _parent (&seq_), _argView (view_)
{
}
@@ -407,7 +407,7 @@ c4_RemapWithViewer::~c4_RemapWithViewer ()
c4_View c4_RemapWithViewer::GetTemplate()
{
- return _tqparent.Clone(); // could probably return _tqparent just as well
+ return _parent.Clone(); // could probably return _parent just as well
}
int c4_RemapWithViewer::GetSize()
@@ -422,7 +422,7 @@ bool c4_RemapWithViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
row_ = ((const c4_IntProp&) map) (_argView[row_]);
- return _tqparent.GetItem(row_, col_, buf_);
+ return _parent.GetItem(row_, col_, buf_);
}
bool c4_RemapWithViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
@@ -432,7 +432,7 @@ bool c4_RemapWithViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
row_ = ((const c4_IntProp&) map) (_argView[row_]);
- _tqparent.SetItem(row_, col_, buf_);
+ _parent.SetItem(row_, col_, buf_);
return true;
}
@@ -445,7 +445,7 @@ c4_CustomViewer* f4_CustRemapWith(c4_Sequence& seq_, const c4_View& view_)
class c4_PairViewer : public c4_CustomViewer
{
- c4_View _tqparent, _argView, _template;
+ c4_View _parent, _argView, _template;
public:
c4_PairViewer (c4_Sequence& seq_, const c4_View& view_);
@@ -460,7 +460,7 @@ public:
};
c4_PairViewer::c4_PairViewer (c4_Sequence& seq_, const c4_View& view_)
- : _tqparent (&seq_), _argView (view_), _template (_tqparent.Clone())
+ : _parent (&seq_), _argView (view_), _template (_parent.Clone())
{
for (int i = 0; i < _argView.NumProperties(); ++i)
_template.AddProperty(_argView.NthProperty(i));
@@ -477,12 +477,12 @@ c4_View c4_PairViewer::GetTemplate()
int c4_PairViewer::GetSize()
{
- return _tqparent.GetSize();
+ return _parent.GetSize();
}
bool c4_PairViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
if (col_ >= v.NumProperties())
{
@@ -496,7 +496,7 @@ bool c4_PairViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
bool c4_PairViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
if (col_ >= v.NumProperties())
{
@@ -511,14 +511,14 @@ bool c4_PairViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
bool c4_PairViewer::InsertRows(int pos_, c4_Cursor value_, int count_)
{
- _tqparent.InsertAt(pos_, *value_, count_);
+ _parent.InsertAt(pos_, *value_, count_);
_argView.InsertAt(pos_, *value_, count_);
return true;
}
bool c4_PairViewer::RemoveRows(int pos_, int count_)
{
- _tqparent.RemoveAt(pos_, count_);
+ _parent.RemoveAt(pos_, count_);
_argView.RemoveAt(pos_, count_);
return true;
}
@@ -532,7 +532,7 @@ c4_CustomViewer* f4_CustPair(c4_Sequence& seq_, const c4_View& view_)
class c4_ConcatViewer : public c4_CustomViewer
{
- c4_View _tqparent, _argView;
+ c4_View _parent, _argView;
public:
c4_ConcatViewer (c4_Sequence& seq_, const c4_View& view_);
@@ -545,7 +545,7 @@ public:
};
c4_ConcatViewer::c4_ConcatViewer (c4_Sequence& seq_, const c4_View& view_)
- : _tqparent (&seq_), _argView (view_)
+ : _parent (&seq_), _argView (view_)
{
}
@@ -555,23 +555,23 @@ c4_ConcatViewer::~c4_ConcatViewer ()
c4_View c4_ConcatViewer::GetTemplate()
{
- return _tqparent.Clone(); // could probably return _tqparent just as well
+ return _parent.Clone(); // could probably return _parent just as well
}
int c4_ConcatViewer::GetSize()
{
- return _tqparent.GetSize() + _argView.GetSize();
+ return _parent.GetSize() + _argView.GetSize();
}
bool c4_ConcatViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
- if (row_ >= _tqparent.GetSize())
+ if (row_ >= _parent.GetSize())
{
v = _argView;
- row_ -= _tqparent.GetSize();
- col_ = v.FindProperty(_tqparent.NthProperty(col_).GetId());
+ row_ -= _parent.GetSize();
+ col_ = v.FindProperty(_parent.NthProperty(col_).GetId());
if (col_ < 0)
return false;
@@ -582,13 +582,13 @@ bool c4_ConcatViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
bool c4_ConcatViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
- if (row_ >= _tqparent.GetSize())
+ if (row_ >= _parent.GetSize())
{
v = _argView;
- row_ -= _tqparent.GetSize();
- col_ = v.FindProperty(_tqparent.NthProperty(col_).GetId());
+ row_ -= _parent.GetSize();
+ col_ = v.FindProperty(_parent.NthProperty(col_).GetId());
d4_assert(col_ >= 0);
}
@@ -605,7 +605,7 @@ c4_CustomViewer* f4_CustConcat(c4_Sequence& seq_, const c4_View& view_)
class c4_RenameViewer : public c4_CustomViewer
{
- c4_View _tqparent, _template;
+ c4_View _parent, _template;
public:
c4_RenameViewer (c4_Sequence& seq_, const c4_Property& old_,
@@ -622,11 +622,11 @@ public:
c4_RenameViewer::c4_RenameViewer (c4_Sequence& seq_, const c4_Property& old_,
const c4_Property& new_)
- : _tqparent (&seq_)
+ : _parent (&seq_)
{
- for (int i = 0; i < _tqparent.NumProperties(); ++i)
+ for (int i = 0; i < _parent.NumProperties(); ++i)
{
- const c4_Property& prop = _tqparent.NthProperty(i);
+ const c4_Property& prop = _parent.NthProperty(i);
_template.AddProperty(prop.GetId() == old_.GetId() ? new_ : prop);
}
}
@@ -642,17 +642,17 @@ c4_View c4_RenameViewer::GetTemplate()
int c4_RenameViewer::GetSize()
{
- return _tqparent.GetSize();
+ return _parent.GetSize();
}
bool c4_RenameViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- return _tqparent.GetItem(row_, col_, buf_);
+ return _parent.GetItem(row_, col_, buf_);
}
bool c4_RenameViewer::SetItem(int row_, int col_, const c4_Bytes& buf_)
{
- _tqparent.SetItem(row_, col_, buf_);
+ _parent.SetItem(row_, col_, buf_);
return true;
}
@@ -666,7 +666,7 @@ c4_CustomViewer* f4_CustRename(c4_Sequence& seq_, const c4_Property& old_,
class c4_GroupByViewer : public c4_CustomViewer
{
- c4_View _tqparent, _keys, _sorted, _temp;
+ c4_View _parent, _keys, _sorted, _temp;
c4_Property _result;
c4_DWordArray _map;
@@ -685,9 +685,9 @@ public:
c4_GroupByViewer::c4_GroupByViewer (c4_Sequence& seq_, const c4_View& keys_,
const c4_Property& result_)
- : _tqparent (&seq_), _keys (keys_), _result (result_)
+ : _parent (&seq_), _keys (keys_), _result (result_)
{
- _sorted = _tqparent.SortOn(_keys);
+ _sorted = _parent.SortOn(_keys);
int n = _sorted.GetSize();
c4_Bytes temp;
@@ -804,7 +804,7 @@ c4_CustomViewer* f4_CustGroupBy(c4_Sequence& seq_, const c4_View& template_,
class c4_JoinPropViewer : public c4_CustomViewer
{
- c4_View _tqparent, _template;
+ c4_View _parent, _template;
c4_ViewProp _sub;
int _subPos, _subWidth;
c4_DWordArray _base, _offset;
@@ -820,20 +820,20 @@ public:
c4_JoinPropViewer::c4_JoinPropViewer (c4_Sequence& seq_,
const c4_ViewProp& sub_, bool outer_)
- : _tqparent (&seq_),
- _sub (sub_), _subPos (_tqparent.FindProperty(sub_.GetId())), _subWidth (0)
+ : _parent (&seq_),
+ _sub (sub_), _subPos (_parent.FindProperty(sub_.GetId())), _subWidth (0)
{
d4_assert(_subPos >= 0);
- for (int k = 0; k < _tqparent.NumProperties(); ++k)
+ for (int k = 0; k < _parent.NumProperties(); ++k)
{
if (k != _subPos)
- _template.AddProperty(_tqparent.NthProperty(k));
+ _template.AddProperty(_parent.NthProperty(k));
else // if there are no rows, then this join does very little anyway
//! OOPS: if this is an unattached view, then the subviews can differ
- if (_tqparent.GetSize() > 0)
+ if (_parent.GetSize() > 0)
{
- c4_View view = sub_ (_tqparent[0]);
+ c4_View view = sub_ (_parent[0]);
for (int l = 0; l < view.NumProperties(); ++l)
{
_template.AddProperty(view.NthProperty(l));
@@ -845,9 +845,9 @@ c4_JoinPropViewer::c4_JoinPropViewer (c4_Sequence& seq_,
_base.SetSize(0, 5);
_offset.SetSize(0, 5);
- for (int i = 0; i < _tqparent.GetSize(); ++i)
+ for (int i = 0; i < _parent.GetSize(); ++i)
{
- c4_View v = _sub (_tqparent[i]);
+ c4_View v = _sub (_parent[i]);
int n = v.GetSize();
if (n == 0 && outer_)
@@ -880,7 +880,7 @@ int c4_JoinPropViewer::GetSize()
bool c4_JoinPropViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
int r = _base.GetAt(row_);
if (col_ >= _subPos)
@@ -890,7 +890,7 @@ bool c4_JoinPropViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
}
else
{
- v = _sub (_tqparent[r]);
+ v = _sub (_parent[r]);
r = _offset.GetAt(row_);
if (r < 0)
return false; // if this is a null row in an outer join
@@ -913,7 +913,7 @@ c4_CustomViewer* f4_CustJoinProp(c4_Sequence& seq_,
class c4_JoinViewer : public c4_CustomViewer
{
- c4_View _tqparent, _argView, _template;
+ c4_View _parent, _argView, _template;
c4_DWordArray _base, _offset;
public:
@@ -928,14 +928,14 @@ public:
c4_JoinViewer::c4_JoinViewer (c4_Sequence& seq_,const c4_View& keys_,
const c4_View& view_, bool outer_)
- : _tqparent (&seq_), _argView (view_.SortOn(keys_))
+ : _parent (&seq_), _argView (view_.SortOn(keys_))
{
// why not in GetTemplate, since we don't need to know this...
- _template = _tqparent.Clone();
+ _template = _parent.Clone();
for (int l = 0; l < _argView.NumProperties(); ++l)
_template.AddProperty(_argView.NthProperty(l));
- c4_View sorted = _tqparent.SortOn(keys_).Project(keys_);
+ c4_View sorted = _parent.SortOn(keys_).Project(keys_);
c4_View temp = _argView.Project(keys_);
_base.SetSize(0, 5);
@@ -945,7 +945,7 @@ c4_JoinViewer::c4_JoinViewer (c4_Sequence& seq_,const c4_View& keys_,
for (int i = 0; i < sorted.GetSize(); ++i)
{
- int orig = _tqparent.GetIndexOf(sorted[i]);
+ int orig = _parent.GetIndexOf(sorted[i]);
d4_assert(orig >= 0);
if (i > 0 && sorted[i] == sorted[i-1])
@@ -1009,7 +1009,7 @@ int c4_JoinViewer::GetSize()
bool c4_JoinViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
int r = _base.GetAt(row_);
if (col_ >= v.NumProperties())
@@ -1030,7 +1030,7 @@ bool c4_JoinViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
#if 0
bool c4_JoinViewer::GetItem(int row_, int col_, c4_Bytes& buf_)
{
- c4_View v = _tqparent;
+ c4_View v = _parent;
int o = 0;
int r = _offset.GetAt(row_);